==> grsync_0.5.orig.tar.gz: grsync-0.5/src/callbacks.h <==
#include <gtk/gtk.h>

#define MAXPATH 2048
#define MAXOPT 100
#define CONFIG_GROUP "__CONFIG"

void load_settings(GtkWidget* main, gchar *session);
void save_settings(GtkWidget* main, gchar *session);
gboolean load_groups(GtkWidget* main, gchar *session);

void
show_browse_source                     (GtkButton       *button,
                                        gpointer         user_data);

void
show_browse_dest                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_play_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dryrun_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_play_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dryrun_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_main_create					               (GtkWindow       *window,
                                        gpointer         user_data);

void
on_main_destroy                        (GtkObject       *object,
                                        gpointer         user_data);

void
on_close_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

void
on_combo_session_changed               (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_session_add_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_session_del_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_session_new_cancel_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_new_session_ok_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_about_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_session_name_editing_done     (GtkCellEditable *celleditable,
                                        gpointer         user_data);

void
show_browse_dest                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_scrolled1_hide                      (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_button_switch_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pause_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_rsync_info_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_main_state_changed                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_rsync_window_state_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

==> grsync_0.5.2-3.tar.gz: grsync-0.5.2/src/callbacks.h <==
#include <gtk/gtk.h>

#define MAXPATH 2048
#define MAXOPT 100
#define CONFIG_GROUP "__CONFIG"

void load_settings(GtkWidget* main, gchar *session);
void save_settings(GtkWidget* main, gchar *session);
gboolean load_groups(GtkWidget* main, gchar *session);

void
show_browse_source                     (GtkButton       *button,
                                        gpointer         user_data);

void
show_browse_dest                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_play_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dryrun_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_play_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dryrun_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_main_create					               (GtkWindow       *window,
                                        gpointer         user_data);

void
on_main_destroy                        (GtkObject       *object,
                                        gpointer         user_data);

void
on_close_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

void
on_combo_session_changed               (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_session_add_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_session_del_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_session_new_cancel_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_new_session_ok_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_about_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_session_name_editing_done     (GtkCellEditable *celleditable,
                                        gpointer         user_data);

void
show_browse_dest                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_scrolled1_hide                      (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_button_switch_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pause_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_rsync_info_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_main_state_changed                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_rsync_window_state_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_rsync_show                          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_rsync_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

#ifdef MAEMO2
gboolean hardware_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
#endif
